[Libreoffice-commits] core.git: android/source
Mert Tümer
merttumer7 at gmail.com
Sat Jan 13 09:58:13 UTC 2018
android/source/res/menu/main.xml | 12 +++++-----
android/source/src/java/org/libreoffice/InvalidationHandler.java | 9 +++++--
2 files changed, 14 insertions(+), 7 deletions(-)
New commits:
commit 5f4c120dd4dcc96329a4b0bcd72d76fb37b42fed
Author: Mert Tümer <merttumer7 at gmail.com>
Date: Mon Jan 8 11:42:16 2018 +0300
tdf#96790 search function in non experimental mode
The patch was sent for the ULAKBIM/Pardus project.
Signed-off-by: Mert Tümer <merttumer7 at gmail.com>
Change-Id: I4e2ecc25eee6535b7d8a89800aaa8135cf517889
Reviewed-on: https://gerrit.libreoffice.org/47568
Tested-by: Jenkins <ci at libreoffice.org>
Reviewed-by: Thorsten Behrens <Thorsten.Behrens at CIB.de>
diff --git a/android/source/res/menu/main.xml b/android/source/res/menu/main.xml
index 0b34d8b5ffac..9a4384af6fd5 100644
--- a/android/source/res/menu/main.xml
+++ b/android/source/res/menu/main.xml
@@ -31,17 +31,19 @@
android:orderInCategory="100"
app:showAsAction="always"/>
- <item android:id="@+id/action_search"
- android:title="@string/action_search"
- android:icon="@drawable/ic_search"
- android:orderInCategory="100"
- app:showAsAction="always"/>
<item android:id="@+id/action_save"
android:title="@string/action_save"
android:orderInCategory="100" />
</group>
+
+ <item android:id="@+id/action_search"
+ android:title="@string/action_search"
+ android:icon="@drawable/ic_search"
+ android:orderInCategory="100"
+ app:showAsAction="always"/>
+
<item android:id="@+id/action_presentation"
android:title="@string/action_presentation"
android:orderInCategory="100"
diff --git a/android/source/src/java/org/libreoffice/InvalidationHandler.java b/android/source/src/java/org/libreoffice/InvalidationHandler.java
index 6cd93ba51615..b3b654346256 100644
--- a/android/source/src/java/org/libreoffice/InvalidationHandler.java
+++ b/android/source/src/java/org/libreoffice/InvalidationHandler.java
@@ -49,8 +49,13 @@ public class InvalidationHandler implements Document.MessageCallback, Office.Mes
@Override
public void messageRetrieved(int messageID, String payload) {
if (!LOKitShell.isEditingEnabled()) {
- // enable handling of hyperlinks even in the Viewer
- if (messageID != Document.CALLBACK_INVALIDATE_TILES && messageID != Document.CALLBACK_HYPERLINK_CLICKED)
+ // enable handling of hyperlinks and search result even in the Viewer
+ if (messageID != Document.CALLBACK_INVALIDATE_TILES
+ && messageID != Document.CALLBACK_HYPERLINK_CLICKED
+ && messageID != Document.CALLBACK_SEARCH_RESULT_SELECTION
+ && messageID != Document.CALLBACK_TEXT_SELECTION
+ && messageID != Document.CALLBACK_TEXT_SELECTION_START
+ && messageID != Document.CALLBACK_TEXT_SELECTION_END)
return;
}
switch (messageID) {
More information about the Libreoffice-commits
mailing list